package net.xinhuamm.xycloud.xinhuamm_xycloud;

import android.net.UrlQuerySanitizer;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.tencent.smtt.sdk.WebView;
import com.xinhuamm.client.ClientUtils;
import com.xinhuamm.client.auto.AutoLoginParams;
import com.xinhuamm.client.bridge.data.ShareData;
import com.xinhuamm.client.callback.O2OAsyncUIDCallback;
import com.xinhuamm.client.callback.O2OPostImageCallback;
import com.xinhuamm.client.ui.fragment.AbsClientFragment;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

import io.flutter.plugin.common.MethodChannel;
import kotlin.Unit;
import kotlin.jvm.functions.Function1;

/**
 * created by 陈明军 at 2021/9/1
 */
public class XYCloudFragment extends AbsClientFragment {

    public static final String KEY_URL = "KEY_URL";
    private String url;

    public static XYCloudFragment newInstance(String url) {
        XYCloudFragment fragment = new XYCloudFragment();
        Bundle bundle = new Bundle();
        bundle.putString(KEY_URL, url);
        fragment.setArguments(bundle);
        return fragment;
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater layoutInflater, @Nullable ViewGroup viewGroup, @Nullable Bundle bundle) {
        if (getArguments() != null) {
            url = getArguments().getString(KEY_URL);
        }
        return super.onCreateView(layoutInflater, viewGroup, bundle);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle bundle) {
        super.onViewCreated(view, bundle);
        WebView.setWebContentsDebuggingEnabled(XYCloudManager.INSTANCE.getCloudDebug());
    }

    @Override
    public String getUrl() {
        return url;
    }

    @Override
    public String getThemeColor() {
        return XYCloudManager.INSTANCE.getThemeColor();
    }

    @Override
    public void getUserId(@NonNull O2OAsyncUIDCallback o2OAsyncUIDCallback) {
        XYCloudManager.INSTANCE.getUserId(userId -> {
            o2OAsyncUIDCallback.setUserId(userId);
            return null;
        });
    }

    @Override
    public String getUserAgent() {
        return XYCloudManager.INSTANCE.getUserAgent();
    }

    @Override
    public void doLogin(AutoLoginParams params) {
        XYCloudManager.INSTANCE.isLogin(isLogin -> {
            if (isLogin) {
                // 用户登录时直接走免登请求逻辑
                autoLogin(params.getRyredirect());
            } else {
                XYCloudManager.INSTANCE.login(null);
            }
            return null;
        });
    }

    private void autoLogin(String url) {
        XYCloudLoginUtil.autoLogin(url, this::loadUrl);
    }

    @Override
    public void jsCallNative(String actionName, String json) {
        super.jsCallNative(actionName, json);
        JSONObject object;
        JSONObject parameterJson;
        try {
            object = new JSONObject(json);
            Object parameterObject = object.get("parameters");
            parameterJson = (JSONObject) parameterObject;
        } catch (JSONException ex) {
            throw new RuntimeException(ex);
        }
        switch (actionName) {
            case "getUserInfo":
                XYCloudManager.INSTANCE.getUserInfo(new Function1<Map<String, String>, Unit>() {
                    @Override
                    public Unit invoke(Map<String, String> result) {
                        if (!isLogin(result) && parameterJson.optBoolean("goLogin")) {
                            XYCloudManager.INSTANCE.login(new MethodChannel.Result() {

                                @Override
                                public void success(@Nullable Object result) {
                                    JSONObject jsonObject = new JSONObject();
                                    try {
                                        jsonObject.put("data", new JSONObject(String.valueOf(result)));
                                    } catch (JSONException ex) {
                                        throw new RuntimeException(ex);
                                    }
                                    webView.evaluateJavascript(new JsDefaultCallback(object).getCallbackJsAction(jsonObject), null);
                                }

                                @Override
                                public void error(@NonNull String errorCode, @Nullable String errorMessage, @Nullable Object errorDetails) {

                                }

                                @Override
                                public void notImplemented() {

                                }
                            });
                        } else {
                            JSONObject jsonObject = new JSONObject();
                            try {
                                jsonObject.put("data", new JSONObject(String.valueOf(result)));
                            } catch (JSONException ex) {
                                throw new RuntimeException(ex);
                            }
                            webView.evaluateJavascript(new JsDefaultCallback(object).getCallbackJsAction(jsonObject), null);
                        }
                        return null;
                    }
                });
                break;
            case "cloudGetToken":
                XYCloudManager.INSTANCE.invokeFlutterMethod("getToken", null, new MethodChannel.Result() {
                    @Override
                    public void success(@Nullable Object result) {
                        webView.evaluateJavascript(new JsDefaultCallback(object).getCallbackJsAction(result), null);
                    }

                    @Override
                    public void error(@NonNull String errorCode, @Nullable String errorMessage, @Nullable Object errorDetails) {

                    }

                    @Override
                    public void notImplemented() {

                    }
                });
                break;
        }
    }

    private boolean isLogin(@Nullable Object result) {
        if (null == result) return false;
        if (TextUtils.isEmpty(result.toString())) return false;
        try {
            JSONObject userObj = new JSONObject(result.toString());
            if (userObj.has("id")) {
                return !TextUtils.isEmpty(userObj.optString("id"));
            }
            return false;
        } catch (JSONException ex) {
            return false;
        }
    }

    @Override
    public void share(@NonNull ShareData shareData, @Nullable O2OPostImageCallback o2OPostImageCallback) {
        XYCloudManager.INSTANCE.invokeFlutterMethod("share", ClassToMap.objectToMap(shareData), null);
    }

    @Override
    public void openNewPage(String url) {
        if (ClientUtils.isClientUrl(url)) {
            XYCloudActivity.start(context, url);
        } else {
            if (!TextUtils.isEmpty(url) && url.startsWith("openMini")) {
                parseMiniProgram(url);
                return;
            }
            XYCloudActivity.start(context, url);
        }
    }

    public void parseMiniProgram(String url) {
        if (url == null || !url.contains("openMini")) {
            return;
        }
        HashMap<String, String> paramsMap = getUrlParameters(url);
        XYCloudManager.INSTANCE.invokeFlutterMethod("openMini", paramsMap, null);
//        String code = Uri.decode(paramsMap.get("code"));
//        String path = Uri.decode(paramsMap.get("path"));
//        MiniAppUtil.goToMiniApp(context, path, code, "");
    }

    public HashMap<String, String> getUrlParameters(String url) {
        HashMap<String, String> paramsMap = new HashMap<>();
        UrlQuerySanitizer sanitizer = new UrlQuerySanitizer();
        sanitizer.setAllowUnregisteredParamaters(true);
        sanitizer.setUnregisteredParameterValueSanitizer(UrlQuerySanitizer.getAllButNulLegal());
        sanitizer.parseUrl(url != null ? url : "");
        Set<String> query = sanitizer.getParameterSet();
        if (!query.isEmpty()) {
            TreeSet<String> treeQuery = new TreeSet<>(query);
            for (String key : treeQuery) {
                String value = sanitizer.getValue(key);
                paramsMap.put(key, value);
            }
        }
        return paramsMap;
    }

}
