//
//  XYCloudManager.m
//  xinhuamm_xycloud
//
//  Created by 邓付磊 on 2023/10/30.
//

#import "XYCloudManager.h"
#import <YYModel/YYModel.h>
#import "XYCloudGlobalConfig.h"
#import "XinhuammXycloudPlugin.h"

@interface XYCloudManager()<XYO2OModuleServeDelegate>

@end

@implementation XYCloudManager

/// 缓存中获取XYCloudManager 实例，防止被释放，否者XYO2OModuleServeDelegate 不会执行
/// - Parameter url:url
+ (instancetype)managerWithUrl:(NSString *)url {
    XYCloudManager *manager = [[XYCloudGlobalConfig shareInstance].cacheManagers objectForKey:url];
    if (!manager) {
         manager = [[XYCloudManager alloc] init];
        [[XYCloudGlobalConfig shareInstance].cacheManagers setObject:manager forKey:url];
    }
    manager.url = url;
    return manager;
}

#pragma mark -public

- (XYO2OModule *)setupMoudle {
    XYO2OModule *module = [[XYO2OModule alloc] init];
    module.o2oUrl       = self.url;
    module.userId = self.userId;
    module.o2oViewFrame = self.o2oViewFrame;
    module.showNavigationBar = self.showNavigationBar;
    module.delegate  = self;
    module.themeColor = [XYCloudGlobalConfig shareInstance].themeColor;
    module.navigationColor = [XYCloudGlobalConfig shareInstance].navigationColor;
    module.userAgent = [XYCloudGlobalConfig shareInstance].userAgent;
    module.weixinSchemeUrl = [XYCloudGlobalConfig shareInstance].weixinSchemeUrl;
    module.appUrlScheme = [XYCloudGlobalConfig shareInstance].appUrlScheme;

    return module;
}

/// 进入O2O页面
- (void)enterO2OPageFromController:(UIViewController *)controller isPush:(BOOL)isPush {
    
    XYO2OModule *module = [self setupMoudle];
    // 获取惠⽣活实例⻚⾯
    XYO2OViewController *vc = [[XYO2OViewController alloc] init];
    vc.o2oModule = module;
    if (!controller) {
        controller = [[UIApplication sharedApplication].delegate window].rootViewController;
    }
    if (isPush) {
        if (controller.navigationController) {
            [controller.navigationController pushViewController:vc animated:YES];
        } else {
            UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:vc];
            nav.modalPresentationStyle = UIModalPresentationFullScreen;
            [controller presentViewController:nav animated:YES completion:nil];
        }
    } else {
        UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:vc];
        nav.modalPresentationStyle = UIModalPresentationFullScreen;
        [controller presentViewController:nav animated:YES completion:nil];
    }
}


#pragma mark - XYO2OModuleServeDelegate

/// 公有云获取token - 替换免登逻辑 - 参考XYWebViewJSBridgeManager
- (void)getCloudTokenWith:(NSDictionary *)parameters block:(void(^)(NSDictionary *data))block {
    [[XinhuammXycloudPlugin instance] getCloudTokenWith:parameters block:block];
}

/// 获取用户信息 
- (void)getUserInfoWith:(NSDictionary *)parameters block:(void(^)(NSDictionary *data))block {
    [[XinhuammXycloudPlugin instance] getUserInfoWith:parameters block:block];
}

- (void)bindCurrentUserId:(void (^)(NSString * _Nonnull))userIdBlock {

//    if (userIdBlock) {
//        if (![[XYCloudManager shareInstance] isLogin]) {
//            userIdBlock(@"");
//        } else {
//            userIdBlock([XYCloudManager shareInstance].userId?:@"");
//        }
//    }
}



- (void)bindryLoginUrlWith:(NSString *)ryredirect application:(NSString *)application bindType:(BOOL)bindType ryLogin:(void (^)(NSString * _Nonnull, BOOL, NSString * _Nonnull))ryBlock {
    if (ryBlock) {
        ryBlock(@"", bindType, ryredirect);
    }
}


/// 分享
/// @param shareDic 分享参数：{"title":"标题", "description":"描述", "url":"链接",  "imageUrl":"分享图片",  "minPath":"小程序路径", "minId":"小程序id", "minType":2}
/// @param getPosterBlock 获取海报block，如果调用了 native 调用js 获取海报的方法
- (void)jsShareWithParameter:(NSDictionary *)shareDic getPosterBlock:(void (^)(BOOL))getPosterBlock {
    [[XinhuammXycloudPlugin instance] shareWithParameter:shareDic getPosterBlock:getPosterBlock];
}

@end
