## 新移云Flutter SDK对接文档

> 对接时若遇到任何冲突及问题，请联系陈明军（电话：17858939680）

### SDK依赖

**pubspec.yaml** 文件中引入

```yaml
dependencies:
  flutter:
    sdk: flutter
  # 新增
  xinhuamm_xycloud: ^1.0.8
```

### 代码引用

```dart
import 'package:xinhuamm_xycloud/xinhuamm_xycloud.dart';

final _xinhuammXycloudPlugin = XinhuammXycloud();
```

### 全局配置

```dart
void setCloudGlobalConfig() {
  _xinhuammXycloudPlugin.setCloudGlobalConfig({
    "weixinSchemeUrl": "微信支付协议",
    "appUrlScheme": "支付宝支付协议",
    "userAgent": "xinhuamm",
    "themeColor": "#f38242",
    "showNavigationBar": false,
    "isDebug": false
  });
}
```

### 全局回调

```dart
void setCloudMethodCallHandler() {
  _xinhuammXycloudPlugin.setCloudMethodCallHandler((call) {
    if ("login" == call.method) {
      print("打开登录页");
      Completer<dynamic> completer = Completer<dynamic>();
      // 打开登录页面，注释代码也请仔细查看
      // openLoginPage((String userId) {
      //   // 回调函数，处理登录成功后的逻辑
      //   print("用户登录成功，userId: $userId");
      //   completer.complete({
      //     "userId": userId,
      //   });
      //   // 登录取消或登录失败后的逻辑也请回调执行completer，传空即可
      // });
      // 等待Completer完成，将其Future返回
      return completer.future;
    } else if ("getUserInfo" == call.method) {
      // 获取用户标识，判断用户是否登录或切换用户
      /* {
        "userId":"用户标识",
      } */
      print("获取用户标识");
      return Future.value({
        "userId": "用户标识",
      });
    } else if ("getToken" == call.method) {
      // 获取免登接口请求参数。返回：json字符串
      /* {
        "token":"用户token",
      } */
      print("获取免登信息");
      return Future.value({
        "token": "用户token",
      });
    } else if ("share" == call.method) {
      // 调用分享功能，call中带有分享参数:
      /* {
      "title":"分享标题",
      "description":"分享摘要",
      "imageUrl":"分享图片",
      "url":"分享链接",
      } */
      String title = call.arguments['title'];
      String description = call.arguments['description'];
      String imageUrl = call.arguments['imageUrl'];
      String url = call.arguments['url'];
      print("分享");
    }
    return Future.value(null);
  });
}
```

### 打开新移云页面

```dart
void openCloudPage() {
  _xinhuammXycloudPlugin.openCloudPage("新移云地址");
}
```

### 获取新移云页面

```dart
Widget getXYCloudFlutterWebView() {
  const String viewType = 'XYCloudFlutterWebView';
  const String url = '新移云地址';
  const Map<String, dynamic> creationParam = {'url': url};
  const MessageCodec creationParamsCodec = StandardMessageCodec();
  if (defaultTargetPlatform == TargetPlatform.android) {
    return const AndroidView(
      viewType: viewType,
      creationParams: creationParam,
      creationParamsCodec: creationParamsCodec,
    );
  } else if (defaultTargetPlatform == TargetPlatform.iOS) {
    return const UiKitView(
      viewType: viewType,
      creationParams: creationParam,
      creationParamsCodec: creationParamsCodec,
    );
  }
  return Container();
}
```

### 处理扫码结果

```dart
void handleScanResult(String scanResult) async {
  bool handled = await _xinhuammXycloudPlugin.handleScanResult(scanResult);
  if (handled) {
    print("sdk内部已处理，外部无需处理");
  } else {
    print("sdk内部未处理，外部需处理");
  }
}
```